# radix-tree

[![PyPI - Version](https://img.shields.io/pypi/v/radix-tree.svg)](https://pypi.org/project/radix-tree)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/radix-tree.svg)](https://pypi.org/project/radix-tree)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install radix-tree
```

## License

`radix-tree` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
